"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanBody = scanBody;
const sqlInjectionDetector_1 = require("../detectors/sqlInjectionDetector");
const xssDetector_1 = require("../detectors/xssDetector");
const scriptInjectionDetector_1 = require("../detectors/scriptInjectionDetector");
function scanBody(body, options) {
    const issues = [];
    const { keys, values, detectSentences, detectReservedWords } = options;
    if (keys) {
        for (const key of Object.keys(body)) {
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(key)) {
                issues.push(`SQL Sentence detected in body key ${key}`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(key)) {
                issues.push(`SQL Injection detected in body key ${key}`);
            }
            if ((0, xssDetector_1.detectXSS)(key)) {
                issues.push(`XSS detected in body key ${key}`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(key)) {
                issues.push(`Script Injection detected in body key ${key}`);
            }
        }
    }
    if (values) {
        for (const [key, value] of Object.entries(body)) {
            const valueString = String(value);
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(valueString)) {
                issues.push(`SQL Sentence detected in body value at key ${key}: ${valueString}`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(valueString)) {
                issues.push(`SQL Injection detected in body value at key ${key}: ${valueString}`);
            }
            if ((0, xssDetector_1.detectXSS)(valueString)) {
                issues.push(`XSS detected in body value at key ${key}: ${valueString}`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(valueString)) {
                issues.push(`Script Injection detected in body value at key ${key}: ${valueString}`);
            }
        }
    }
    return issues;
}
//# sourceMappingURL=scanBody.js.map