"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanHeaders = scanHeaders;
const sqlInjectionDetector_1 = require("../detectors/sqlInjectionDetector");
const xssDetector_1 = require("../detectors/xssDetector");
const scriptInjectionDetector_1 = require("../detectors/scriptInjectionDetector");
function scanHeaders(headers, options) {
    const issues = [];
    const { keys, values, detectSentences, detectReservedWords } = options;
    for (const [key, value] of Object.entries(headers)) {
        // Scan header keys
        if (keys) {
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(key)) {
                issues.push(`SQL Sentence detected in header key: "${key}".`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(key)) {
                issues.push(`SQL Injection detected in header key: "${key}".`);
            }
            if ((0, xssDetector_1.detectXSS)(key)) {
                issues.push(`XSS detected in header key: "${key}".`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(key)) {
                issues.push(`Script Injection detected in header key: "${key}".`);
            }
        }
        // Scan header values
        if (values) {
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(value)) {
                issues.push(`SQL Sentence detected in header value at key "${key}": "${value}".`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(value)) {
                issues.push(`SQL Injection detected in header value at key "${key}": "${value}".`);
            }
            if ((0, xssDetector_1.detectXSS)(value)) {
                issues.push(`XSS detected in header value at key "${key}": "${value}".`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(value)) {
                issues.push(`Script Injection detected in header value at key "${key}": "${value}".`);
            }
        }
    }
    return issues;
}
//# sourceMappingURL=scanHeaders.js.map